
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_BOOK_ENUMTYPES_H
#define E_BOOK_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-book-types.h" */
#define E_TYPE_BOOK_STATUS	(e_book_status_get_type())
GType e_book_status_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_BOOK_ENUMTYPES_H */

/* Generated data ends here */

